@@ -22,7 +22,7 @@ class EventCallback(BwApi.CallbackBase):
     def Run(self, garment_id, callback_id, data_string):
 
         try:
-            BwApi.WndMessageBox(callback_id + '', BwApi.BW_API_MB_OK)
+            BwApi.WndMessageBox(str(callback_id), BwApi.BW_API_MB_OK)
             if callback_id == 0:
                 # TODO params + right actions
                 importFile()
